// Generated by the protocol buffer compiler.  DO NOT EDIT!
// source: world_control.proto

#ifndef GOOGLE_PROTOBUF_INCLUDED_world_5fcontrol_2eproto
#define GOOGLE_PROTOBUF_INCLUDED_world_5fcontrol_2eproto

#include <limits>
#include <string>

#include <google/protobuf/port_def.inc>
#if PROTOBUF_VERSION < 3018000
#error This file was generated by a newer version of protoc which is
#error incompatible with your Protocol Buffer headers. Please update
#error your headers.
#endif
#if 3018001 < PROTOBUF_MIN_PROTOC_VERSION
#error This file was generated by an older version of protoc which is
#error incompatible with your Protocol Buffer headers. Please
#error regenerate this file with a newer version of protoc.
#endif

#include <google/protobuf/port_undef.inc>
#include <google/protobuf/io/coded_stream.h>
#include <google/protobuf/arena.h>
#include <google/protobuf/arenastring.h>
#include <google/protobuf/generated_message_table_driven.h>
#include <google/protobuf/generated_message_util.h>
#include <google/protobuf/metadata_lite.h>
#include <google/protobuf/generated_message_reflection.h>
#include <google/protobuf/message.h>
#include <google/protobuf/repeated_field.h>  // IWYU pragma: export
#include <google/protobuf/extension_set.h>  // IWYU pragma: export
#include <google/protobuf/unknown_field_set.h>
#include "world_reset.pb.h"
#ifndef _MSC_VER
#pragma GCC system_header
#pragma GCC diagnostic ignored "-Wshadow"
#pragma GCC diagnostic ignored "-Wunused-parameter"
#endif
#include <boost/shared_ptr.hpp>
#include <gazebo/util/system.hh>
#include "gazebo/msgs/MsgFactory.hh"
// @@protoc_insertion_point(includes)
#include <google/protobuf/port_def.inc>
#define PROTOBUF_INTERNAL_EXPORT_world_5fcontrol_2eproto GZ_MSGS_VISIBLE
PROTOBUF_NAMESPACE_OPEN
namespace internal {
class AnyMetadata;
}  // namespace internal
PROTOBUF_NAMESPACE_CLOSE

// Internal implementation detail -- do not use these members.
struct GZ_MSGS_VISIBLE TableStruct_world_5fcontrol_2eproto {
  static const ::PROTOBUF_NAMESPACE_ID::internal::ParseTableField entries[]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::AuxiliaryParseTableField aux[]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::ParseTable schema[1]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::FieldMetadata field_metadata[];
  static const ::PROTOBUF_NAMESPACE_ID::internal::SerializationTable serialization_table[];
  static const ::PROTOBUF_NAMESPACE_ID::uint32 offsets[];
};
GZ_MSGS_VISIBLE extern const ::PROTOBUF_NAMESPACE_ID::internal::DescriptorTable descriptor_table_world_5fcontrol_2eproto;
namespace gazebo {
namespace msgs {
class WorldControl;
struct WorldControlDefaultTypeInternal;
GZ_MSGS_VISIBLE extern WorldControlDefaultTypeInternal _WorldControl_default_instance_;
}  // namespace msgs
}  // namespace gazebo
PROTOBUF_NAMESPACE_OPEN
template<> GZ_MSGS_VISIBLE ::gazebo::msgs::WorldControl* Arena::CreateMaybeMessage<::gazebo::msgs::WorldControl>(Arena*);
PROTOBUF_NAMESPACE_CLOSE
namespace gazebo {
namespace msgs {

// ===================================================================

class GZ_MSGS_VISIBLE WorldControl final :
    public ::PROTOBUF_NAMESPACE_ID::Message /* @@protoc_insertion_point(class_definition:gazebo.msgs.WorldControl) */ {
 public:
  inline WorldControl() : WorldControl(nullptr) {}
  ~WorldControl() override;
  explicit constexpr WorldControl(::PROTOBUF_NAMESPACE_ID::internal::ConstantInitialized);

  WorldControl(const WorldControl& from);
  WorldControl(WorldControl&& from) noexcept
    : WorldControl() {
    *this = ::std::move(from);
  }

  inline WorldControl& operator=(const WorldControl& from) {
    CopyFrom(from);
    return *this;
  }
  inline WorldControl& operator=(WorldControl&& from) noexcept {
    if (this == &from) return *this;
    if (GetOwningArena() == from.GetOwningArena()
  #ifdef PROTOBUF_FORCE_COPY_IN_MOVE
        && GetOwningArena() != nullptr
  #endif  // !PROTOBUF_FORCE_COPY_IN_MOVE
    ) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  inline const ::PROTOBUF_NAMESPACE_ID::UnknownFieldSet& unknown_fields() const {
    return _internal_metadata_.unknown_fields<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>(::PROTOBUF_NAMESPACE_ID::UnknownFieldSet::default_instance);
  }
  inline ::PROTOBUF_NAMESPACE_ID::UnknownFieldSet* mutable_unknown_fields() {
    return _internal_metadata_.mutable_unknown_fields<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>();
  }

  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* descriptor() {
    return GetDescriptor();
  }
  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  static const ::PROTOBUF_NAMESPACE_ID::Reflection* GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  static const WorldControl& default_instance() {
    return *internal_default_instance();
  }
  static inline const WorldControl* internal_default_instance() {
    return reinterpret_cast<const WorldControl*>(
               &_WorldControl_default_instance_);
  }
  static constexpr int kIndexInFileMessages =
    0;

  friend void swap(WorldControl& a, WorldControl& b) {
    a.Swap(&b);
  }
  inline void Swap(WorldControl* other) {
    if (other == this) return;
    if (GetOwningArena() == other->GetOwningArena()) {
      InternalSwap(other);
    } else {
      ::PROTOBUF_NAMESPACE_ID::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(WorldControl* other) {
    if (other == this) return;
    GOOGLE_DCHECK(GetOwningArena() == other->GetOwningArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  inline WorldControl* New() const final {
    return new WorldControl();
  }

  WorldControl* New(::PROTOBUF_NAMESPACE_ID::Arena* arena) const final {
    return CreateMaybeMessage<WorldControl>(arena);
  }
  using ::PROTOBUF_NAMESPACE_ID::Message::CopyFrom;
  void CopyFrom(const WorldControl& from);
  using ::PROTOBUF_NAMESPACE_ID::Message::MergeFrom;
  void MergeFrom(const WorldControl& from);
  private:
  static void MergeImpl(::PROTOBUF_NAMESPACE_ID::Message* to, const ::PROTOBUF_NAMESPACE_ID::Message& from);
  public:
  PROTOBUF_ATTRIBUTE_REINITIALIZES void Clear() final;
  bool IsInitialized() const final;

  size_t ByteSizeLong() const final;
  const char* _InternalParse(const char* ptr, ::PROTOBUF_NAMESPACE_ID::internal::ParseContext* ctx) final;
  ::PROTOBUF_NAMESPACE_ID::uint8* _InternalSerialize(
      ::PROTOBUF_NAMESPACE_ID::uint8* target, ::PROTOBUF_NAMESPACE_ID::io::EpsCopyOutputStream* stream) const final;
  int GetCachedSize() const final { return _cached_size_.Get(); }

  private:
  void SharedCtor();
  void SharedDtor();
  void SetCachedSize(int size) const final;
  void InternalSwap(WorldControl* other);
  friend class ::PROTOBUF_NAMESPACE_ID::internal::AnyMetadata;
  static ::PROTOBUF_NAMESPACE_ID::StringPiece FullMessageName() {
    return "gazebo.msgs.WorldControl";
  }
  protected:
  explicit WorldControl(::PROTOBUF_NAMESPACE_ID::Arena* arena,
                       bool is_message_owned = false);
  private:
  static void ArenaDtor(void* object);
  inline void RegisterArenaDtor(::PROTOBUF_NAMESPACE_ID::Arena* arena);
  public:

  static const ClassData _class_data_;
  const ::PROTOBUF_NAMESPACE_ID::Message::ClassData*GetClassData() const final;

  ::PROTOBUF_NAMESPACE_ID::Metadata GetMetadata() const final;

  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------

  enum : int {
    kResetFieldNumber = 4,
    kPauseFieldNumber = 1,
    kStepFieldNumber = 2,
    kMultiStepFieldNumber = 3,
    kSeedFieldNumber = 5,
  };
  // optional .gazebo.msgs.WorldReset reset = 4;
  bool has_reset() const;
  private:
  bool _internal_has_reset() const;
  public:
  void clear_reset();
  const ::gazebo::msgs::WorldReset& reset() const;
  PROTOBUF_MUST_USE_RESULT ::gazebo::msgs::WorldReset* release_reset();
  ::gazebo::msgs::WorldReset* mutable_reset();
  void set_allocated_reset(::gazebo::msgs::WorldReset* reset);
  private:
  const ::gazebo::msgs::WorldReset& _internal_reset() const;
  ::gazebo::msgs::WorldReset* _internal_mutable_reset();
  public:
  void unsafe_arena_set_allocated_reset(
      ::gazebo::msgs::WorldReset* reset);
  ::gazebo::msgs::WorldReset* unsafe_arena_release_reset();

  // optional bool pause = 1;
  bool has_pause() const;
  private:
  bool _internal_has_pause() const;
  public:
  void clear_pause();
  bool pause() const;
  void set_pause(bool value);
  private:
  bool _internal_pause() const;
  void _internal_set_pause(bool value);
  public:

  // optional bool step = 2;
  bool has_step() const;
  private:
  bool _internal_has_step() const;
  public:
  void clear_step();
  bool step() const;
  void set_step(bool value);
  private:
  bool _internal_step() const;
  void _internal_set_step(bool value);
  public:

  // optional uint32 multi_step = 3;
  bool has_multi_step() const;
  private:
  bool _internal_has_multi_step() const;
  public:
  void clear_multi_step();
  ::PROTOBUF_NAMESPACE_ID::uint32 multi_step() const;
  void set_multi_step(::PROTOBUF_NAMESPACE_ID::uint32 value);
  private:
  ::PROTOBUF_NAMESPACE_ID::uint32 _internal_multi_step() const;
  void _internal_set_multi_step(::PROTOBUF_NAMESPACE_ID::uint32 value);
  public:

  // optional uint32 seed = 5;
  bool has_seed() const;
  private:
  bool _internal_has_seed() const;
  public:
  void clear_seed();
  ::PROTOBUF_NAMESPACE_ID::uint32 seed() const;
  void set_seed(::PROTOBUF_NAMESPACE_ID::uint32 value);
  private:
  ::PROTOBUF_NAMESPACE_ID::uint32 _internal_seed() const;
  void _internal_set_seed(::PROTOBUF_NAMESPACE_ID::uint32 value);
  public:

  // @@protoc_insertion_point(class_scope:gazebo.msgs.WorldControl)
 private:
  class _Internal;

  template <typename T> friend class ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper;
  typedef void InternalArenaConstructable_;
  typedef void DestructorSkippable_;
  ::PROTOBUF_NAMESPACE_ID::internal::HasBits<1> _has_bits_;
  mutable ::PROTOBUF_NAMESPACE_ID::internal::CachedSize _cached_size_;
  ::gazebo::msgs::WorldReset* reset_;
  bool pause_;
  bool step_;
  ::PROTOBUF_NAMESPACE_ID::uint32 multi_step_;
  ::PROTOBUF_NAMESPACE_ID::uint32 seed_;
  friend struct ::TableStruct_world_5fcontrol_2eproto;
};
// ===================================================================


// ===================================================================

#ifdef __GNUC__
  #pragma GCC diagnostic push
  #pragma GCC diagnostic ignored "-Wstrict-aliasing"
#endif  // __GNUC__
// WorldControl

// optional bool pause = 1;
inline bool WorldControl::_internal_has_pause() const {
  bool value = (_has_bits_[0] & 0x00000002u) != 0;
  return value;
}
inline bool WorldControl::has_pause() const {
  return _internal_has_pause();
}
inline void WorldControl::clear_pause() {
  pause_ = false;
  _has_bits_[0] &= ~0x00000002u;
}
inline bool WorldControl::_internal_pause() const {
  return pause_;
}
inline bool WorldControl::pause() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.WorldControl.pause)
  return _internal_pause();
}
inline void WorldControl::_internal_set_pause(bool value) {
  _has_bits_[0] |= 0x00000002u;
  pause_ = value;
}
inline void WorldControl::set_pause(bool value) {
  _internal_set_pause(value);
  // @@protoc_insertion_point(field_set:gazebo.msgs.WorldControl.pause)
}

// optional bool step = 2;
inline bool WorldControl::_internal_has_step() const {
  bool value = (_has_bits_[0] & 0x00000004u) != 0;
  return value;
}
inline bool WorldControl::has_step() const {
  return _internal_has_step();
}
inline void WorldControl::clear_step() {
  step_ = false;
  _has_bits_[0] &= ~0x00000004u;
}
inline bool WorldControl::_internal_step() const {
  return step_;
}
inline bool WorldControl::step() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.WorldControl.step)
  return _internal_step();
}
inline void WorldControl::_internal_set_step(bool value) {
  _has_bits_[0] |= 0x00000004u;
  step_ = value;
}
inline void WorldControl::set_step(bool value) {
  _internal_set_step(value);
  // @@protoc_insertion_point(field_set:gazebo.msgs.WorldControl.step)
}

// optional uint32 multi_step = 3;
inline bool WorldControl::_internal_has_multi_step() const {
  bool value = (_has_bits_[0] & 0x00000008u) != 0;
  return value;
}
inline bool WorldControl::has_multi_step() const {
  return _internal_has_multi_step();
}
inline void WorldControl::clear_multi_step() {
  multi_step_ = 0u;
  _has_bits_[0] &= ~0x00000008u;
}
inline ::PROTOBUF_NAMESPACE_ID::uint32 WorldControl::_internal_multi_step() const {
  return multi_step_;
}
inline ::PROTOBUF_NAMESPACE_ID::uint32 WorldControl::multi_step() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.WorldControl.multi_step)
  return _internal_multi_step();
}
inline void WorldControl::_internal_set_multi_step(::PROTOBUF_NAMESPACE_ID::uint32 value) {
  _has_bits_[0] |= 0x00000008u;
  multi_step_ = value;
}
inline void WorldControl::set_multi_step(::PROTOBUF_NAMESPACE_ID::uint32 value) {
  _internal_set_multi_step(value);
  // @@protoc_insertion_point(field_set:gazebo.msgs.WorldControl.multi_step)
}

// optional .gazebo.msgs.WorldReset reset = 4;
inline bool WorldControl::_internal_has_reset() const {
  bool value = (_has_bits_[0] & 0x00000001u) != 0;
  PROTOBUF_ASSUME(!value || reset_ != nullptr);
  return value;
}
inline bool WorldControl::has_reset() const {
  return _internal_has_reset();
}
inline const ::gazebo::msgs::WorldReset& WorldControl::_internal_reset() const {
  const ::gazebo::msgs::WorldReset* p = reset_;
  return p != nullptr ? *p : reinterpret_cast<const ::gazebo::msgs::WorldReset&>(
      ::gazebo::msgs::_WorldReset_default_instance_);
}
inline const ::gazebo::msgs::WorldReset& WorldControl::reset() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.WorldControl.reset)
  return _internal_reset();
}
inline void WorldControl::unsafe_arena_set_allocated_reset(
    ::gazebo::msgs::WorldReset* reset) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(reset_);
  }
  reset_ = reset;
  if (reset) {
    _has_bits_[0] |= 0x00000001u;
  } else {
    _has_bits_[0] &= ~0x00000001u;
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:gazebo.msgs.WorldControl.reset)
}
inline ::gazebo::msgs::WorldReset* WorldControl::release_reset() {
  _has_bits_[0] &= ~0x00000001u;
  ::gazebo::msgs::WorldReset* temp = reset_;
  reset_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::gazebo::msgs::WorldReset* WorldControl::unsafe_arena_release_reset() {
  // @@protoc_insertion_point(field_release:gazebo.msgs.WorldControl.reset)
  _has_bits_[0] &= ~0x00000001u;
  ::gazebo::msgs::WorldReset* temp = reset_;
  reset_ = nullptr;
  return temp;
}
inline ::gazebo::msgs::WorldReset* WorldControl::_internal_mutable_reset() {
  _has_bits_[0] |= 0x00000001u;
  if (reset_ == nullptr) {
    auto* p = CreateMaybeMessage<::gazebo::msgs::WorldReset>(GetArenaForAllocation());
    reset_ = p;
  }
  return reset_;
}
inline ::gazebo::msgs::WorldReset* WorldControl::mutable_reset() {
  ::gazebo::msgs::WorldReset* _msg = _internal_mutable_reset();
  // @@protoc_insertion_point(field_mutable:gazebo.msgs.WorldControl.reset)
  return _msg;
}
inline void WorldControl::set_allocated_reset(::gazebo::msgs::WorldReset* reset) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(reset_);
  }
  if (reset) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(reset));
    if (message_arena != submessage_arena) {
      reset = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, reset, submessage_arena);
    }
    _has_bits_[0] |= 0x00000001u;
  } else {
    _has_bits_[0] &= ~0x00000001u;
  }
  reset_ = reset;
  // @@protoc_insertion_point(field_set_allocated:gazebo.msgs.WorldControl.reset)
}

// optional uint32 seed = 5;
inline bool WorldControl::_internal_has_seed() const {
  bool value = (_has_bits_[0] & 0x00000010u) != 0;
  return value;
}
inline bool WorldControl::has_seed() const {
  return _internal_has_seed();
}
inline void WorldControl::clear_seed() {
  seed_ = 0u;
  _has_bits_[0] &= ~0x00000010u;
}
inline ::PROTOBUF_NAMESPACE_ID::uint32 WorldControl::_internal_seed() const {
  return seed_;
}
inline ::PROTOBUF_NAMESPACE_ID::uint32 WorldControl::seed() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.WorldControl.seed)
  return _internal_seed();
}
inline void WorldControl::_internal_set_seed(::PROTOBUF_NAMESPACE_ID::uint32 value) {
  _has_bits_[0] |= 0x00000010u;
  seed_ = value;
}
inline void WorldControl::set_seed(::PROTOBUF_NAMESPACE_ID::uint32 value) {
  _internal_set_seed(value);
  // @@protoc_insertion_point(field_set:gazebo.msgs.WorldControl.seed)
}

#ifdef __GNUC__
  #pragma GCC diagnostic pop
#endif  // __GNUC__

typedef boost::shared_ptr<gazebo::msgs::WorldControl> WorldControlPtr;
// @@protoc_insertion_point(namespace_scope)

}  // namespace msgs
}  // namespace gazebo

typedef const boost::shared_ptr<gazebo::msgs::WorldControl const> ConstWorldControlPtr;
// @@protoc_insertion_point(global_scope)

#include <google/protobuf/port_undef.inc>
#endif  // GOOGLE_PROTOBUF_INCLUDED_GOOGLE_PROTOBUF_INCLUDED_world_5fcontrol_2eproto
